R/flame.R
pv_flame_condense.Rd
Shows a simplified, condensed view of the flame graph focusing on the hottest paths.
pv_flame_condense(x, n = 10, width = 50)
A profvis object.
Number of hot paths to show.
Width of bars.
Invisibly returns a data frame with path, samples, and pct columns.